Learn R Programming

rcicr (version 1.3.0)

generateGabor: Generate single gabor patch

Description

Generate single gabor patch

Usage

generateGabor(img_size, cycles, angle, phase, sigma, contrast)

Value

The gabor patch image with size img_size.

Arguments

img_size

Integer specifying size of gabor patch in number of pixels.

cycles

Integer specifying number of cycles the sinusoid should span.

angle

Value specifying the angle (rotation) of the sinusoid.

phase

Value specifying phase of sinusoid.

sigma

Value specifying the standard deviation, in pixels, of the Gaussian mask applied on top of the sinusoid.

contrast

Value between -1.0 and 1.0 specifying contrast of sinusoid.

Examples

Run this code
generateGabor(512, 2, 90, pi/2, 25, 1.0)

Run the code above in your browser using DataLab