Generate sinusoid noise pattern
generateNoisePattern(
img_size = 512,
nscales = 5,
noise_type = "sinusoid",
sigma = 25,
pre_0.3.0 = FALSE
)List with two elements: the 3D noise matrix with size img_size, and an indexing
matrix with the same size to easily change contrasts.
Integer specifying size of the noise pattern in number of pixels.
Integer specifying the number of incremental spatial scales. Defaults to 5. Higher numbers will add higher spatial frequency scales.
String specifying noise pattern type (defaults to sinusoid; other options: gabor).
Number specifying the sigma of the Gabor patch if noise_type is set to gabor (defaults to 25).
Boolean specifying whether the noise pattern should be created in a way compatible with older versions of rcicr (< 0.3.0). If you are starting a new project, you should keep this at the default setting (FALSE). There is no reason to set this to TRUE, with the sole exception to recreate behavior of rcicr prior to version 0.3.0.