powered by
Generate single gabor patch
generateGabor(img_size, cycles, angle, phase, sigma, contrast)
The gabor patch image with size img_size.
img_size
Integer specifying size of gabor patch in number of pixels.
Integer specifying number of cycles the sinusoid should span.
Value specifying the angle (rotation) of the sinusoid.
Value specifying phase of sinusoid.
Value specifying the standard deviation, in pixels, of the Gaussian mask applied on top of the sinusoid.
Value between -1.0 and 1.0 specifying contrast of sinusoid.
generateGabor(512, 2, 90, pi/2, 25, 1.0)
Run the code above in your browser using DataLab