Learn R Programming

rcicr (version 1.3.0)

simulateNoiseIntensities: Simulate pixel intensity range for noise

Description

Simulate pixel intensity range for noise

Usage

simulateNoiseIntensities(nrep = 1000, img_size = 512)

Value

Matrix with range of noise intensities for each replication

Arguments

nrep

Number of replications

img_size

Size of noise pattern in pixels (one value equal for width and height)

Examples

Run this code
# nrep and img_size are kept small here so the example is fast; the defaults
# (1000 replications at 512px) are what you want for a real estimate.
simulateNoiseIntensities(nrep = 10, img_size = 64)

Run the code above in your browser using DataLab