powered by
Simulate pixel intensity range for noise
simulateNoiseIntensities(nrep = 1000, img_size = 512)
Matrix with range of noise intensities for each replication
Number of replications
Size of noise pattern in pixels (one value equal for width and height)
# nrep and img_size are kept small here so the example is fast; the defaults # (1000 replications at 512px) are what you want for a real estimate. simulateNoiseIntensities(nrep = 10, img_size = 64)
Run the code above in your browser using DataLab